@@ -3,9 +3,9 @@ from typing import Dict, List
 
 import pyotp
 
-from entity.printable import Printable
-from entity.user import User
-from util.constants import BASE_PATH
+from robinhood_commons.entity.printable import Printable
+from robinhood_commons.entity.user import User
+from robinhood_commons.util.constants import BASE_PATH
 
 PATH: str = f'{BASE_PATH}/users.csv'
 
@@ -13,10 +13,10 @@ PATH: str = f'{BASE_PATH}/users.csv'
 class UserDao(Printable):
 
     @staticmethod
-    def get_users() -> List[User]:
+    def get_users(path: str = PATH) -> List[User]:
         users: List[User] = []
         first: bool = True
-        with open(PATH) as csvfile:
+        with open(path) as csvfile:
             reader = csv.reader(csvfile)
             for row in reader:
                 if first:
