@@ -1,8 +1,6 @@
 
 MAIN_EMAIL: str = 'mhowell234@gmail.com'
-BASE_PATH: str = './'
-BASE_PATH3: str = '/Users/mhowell234/code/robinhood/'
-BASE_PATH2: str = '/opt/code/robinhood/'
+BASE_PATH: str = '/robinhood_data/'
 LOG_DIR: str = f'{BASE_PATH}output/logs/'
 TMP_DIR = f'{BASE_PATH}tmp/'
 STOCKS_FILE_PATH: str = f'{TMP_DIR}stocks.json'
